@@ -1,6 +1,18 @@
-from notecoin.huobi.model.market import *
-from notecoin.huobi.service.market import (MarketService, MarketServiceSocket,
-                                           MarketServiceSub)
+import json
+import time
+
+from notecoin.huobi.connection import (RestApiSyncClient, SubscribeClient,
+                                       WebSocketReqClient)
+from notecoin.huobi.constant import (CandlestickInterval, DepthStep,
+                                     HttpMethod, MbpLevel)
+from notecoin.huobi.utils import (get_current_timestamp, kline_channel,
+                                  market_detail_channel,
+                                  price_depth_bbo_channel, price_depth_channel,
+                                  request_kline_channel,
+                                  request_market_detail_channel,
+                                  request_price_depth_channel,
+                                  request_trade_detail_channel,
+                                  trade_detail_channel)
 from notecoin.huobi.utils.input_checker import (check_in_list, check_range,
                                                 check_should_not_none,
                                                 check_symbol,
@@ -9,7 +21,7 @@ from notecoin.huobi.utils.input_checker import (check_in_list, check_range,
 
 class MarketClient(object):
 
-    def __init__(self, **kwargs):
+    def __init__(self, *args, **kwargs):
         """
         Create the request client instance.
         :param kwargs: The option of request connection.
@@ -19,9 +31,9 @@ class MarketClient(object):
             init_log: to init logger
         """
         self.__kwargs = kwargs
-        self.market_service = MarketService(**kwargs)
-        self.market_service_sub = MarketServiceSub(**kwargs)
-        self.market_service_socket = MarketServiceSocket(**kwargs)
+        self.market_service = RestApiSyncClient(*args, **kwargs)
+        self.market_service_sub = SubscribeClient(**kwargs)
+        self.market_service_socket = WebSocketReqClient(**kwargs)
 
     def get_candlestick(self, symbol, period, size=200):
         """
@@ -41,10 +53,10 @@ class MarketClient(object):
             "period": period,
             "size": size
         }
+        channel = "/market/history/kline"
+        return self.market_service.request_process(HttpMethod.GET, channel, params)
 
-        return self.market_service.get_candle_stick_service(params)
-
-    def sub_candlestick(self, symbols: 'str', interval: 'CandlestickInterval', callback, error_handler):
+    def sub_candlestick(self, symbols: str, interval: CandlestickInterval, callback, error_handler):
         """
         Subscribe candlestick/kline event. If the candlestick/kline is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -66,13 +78,14 @@ class MarketClient(object):
         check_should_not_none(interval, "interval")
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-            "interval": interval,
-        }
-        self.market_service_sub.sub_candle_stick_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(kline_channel(symbol, interval))
+                time.sleep(0.01)
 
-    def req_candlestick(self, symbols: 'str', interval: 'CandlestickInterval', callback,
+        self.market_service_sub.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def req_candlestick(self, symbols: str, interval: CandlestickInterval, callback,
                         from_ts_second=None, end_ts_second=None, error_handler=None):
         """
         Subscribe candlestick/kline event. If the candlestick/kline is updated,
@@ -97,15 +110,14 @@ class MarketClient(object):
         check_should_not_none(interval, "interval")
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-            "interval": interval,
-            "from_ts_second": from_ts_second,
-            "end_ts_second": end_ts_second
-        }
-        self.market_service_socket.req_candle_stick_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(request_kline_channel(symbol, interval, from_ts_second, end_ts_second))
+                time.sleep(0.01)
 
-    def get_price_depth(self, symbol: str, depth_type: str, depth_size: int = None) -> PriceDepth:
+        self.market_service_socket.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def get_price_depth(self, symbol: str, depth_type: str, depth_size: int = None):
         """
         Get the Market Depth of a symbol.
 
@@ -117,6 +129,7 @@ class MarketClient(object):
                            size is in [5, 10, 20], default is 20.
         :return: Market Depth data.
         """
+        channel = "/market/depth"
 
         check_symbol(symbol)
         check_in_list(depth_type, [DepthStep.STEP0, DepthStep.STEP1, DepthStep.STEP2, DepthStep.STEP3, DepthStep.STEP4,
@@ -126,7 +139,8 @@ class MarketClient(object):
             "type": depth_type,
             # "depth": depth_size
         }
-        ret_data = self.market_service.get_price_depth_service(params)
+
+        ret_data = self.market_service.request_process(HttpMethod.GET, channel, params)
 
         if depth_size is not None:
             if (ret_data.bids is not None) and (len(ret_data.bids) > depth_size):
@@ -139,12 +153,7 @@ class MarketClient(object):
 
     @staticmethod
     def get_depth_step_list():
-        return [DepthStep.STEP0,
-                DepthStep.STEP1,
-                DepthStep.STEP2,
-                DepthStep.STEP3,
-                DepthStep.STEP4,
-                DepthStep.STEP5]
+        return [DepthStep.STEP0, DepthStep.STEP1, DepthStep.STEP2, DepthStep.STEP3, DepthStep.STEP4, DepthStep.STEP5]
 
     @staticmethod
     def get_valid_depth_step(value, defalut_value):
@@ -154,7 +163,7 @@ class MarketClient(object):
         else:
             return defalut_value
 
-    def sub_price_depth(self, symbols: 'str', depth_step: 'str', callback, error_handler=None):
+    def sub_price_depth(self, symbols: str, depth_step: str, callback, error_handler=None):
         """
         Subscribe price depth event. If the price depth is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -173,16 +182,17 @@ class MarketClient(object):
         """
         symbol_list = symbols.split(",")
         check_symbol_list(symbol_list)
-        new_step = MarketClient.get_valid_depth_step(value=depth_step, defalut_value=DepthStep.STEP0)
+        step = MarketClient.get_valid_depth_step(value=depth_step, defalut_value=DepthStep.STEP0)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-            "step": new_step,
-        }
-        self.market_service_sub.sub_price_depth_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(price_depth_channel(symbol, step))
+                time.sleep(0.01)
 
-    def sub_pricedepth_bbo(self, symbols: 'str', callback, error_handler=None):
+        self.market_service_sub.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def sub_price_depth_bbo(self, symbols: str, callback, error_handler=None):
         """
         Subscribe price depth event. If the price depth is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -202,12 +212,14 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
-        self.market_service_sub.sub_price_depth_bbo_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(price_depth_bbo_channel(symbol))
+                time.sleep(0.01)
 
-    def req_price_depth(self, symbols: 'str', depth_step: 'str', callback, error_handler=None):
+        self.market_service_sub.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def req_price_depth(self, symbols: str, depth_step: str, callback, error_handler=None):
         """
         Subscribe price depth event. If the price depth is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -226,31 +238,34 @@ class MarketClient(object):
         """
         symbol_list = symbols.split(",")
         check_symbol_list(symbol_list)
-        new_step = MarketClient.get_valid_depth_step(value=depth_step, defalut_value=DepthStep.STEP0)
+        step = MarketClient.get_valid_depth_step(value=depth_step, defalut_value=DepthStep.STEP0)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-            "step": new_step,
-        }
-        self.market_service_socket.req_price_depth_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(request_price_depth_channel(symbol, step))
+                time.sleep(0.01)
 
-    def get_market_detail(self, symbol: 'str') -> MarketDetail:
+        self.market_service_socket.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def get_market_detail(self, symbol: str):
         """
         Get trade statistics in 24 hours.
 
         :param symbol: The symbol, like "btcusdt". (mandatory)
         :return: Trade statistics.
         """
+        channel = "/market/detail"
 
         check_symbol(symbol)
 
         params = {
             "symbol": symbol,
         }
-        return self.market_service.get_market_detail_service(params)
 
-    def sub_market_detail(self, symbols: 'str', callback, error_handler=None):
+        return self.market_service.request_process(HttpMethod.GET, channel, params)
+
+    def sub_market_detail(self, symbols: str, callback, error_handler=None):
         """
         Subscribe 24 hours trade statistics event. If statistics is generated,
         server will send the data to client and onReceive in callback will be called.
@@ -269,12 +284,14 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
-        self.market_service_sub.sub_market_detail_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(market_detail_channel(symbol))
+                time.sleep(0.01)
 
-    def req_market_detail(self, symbols: 'str', callback, error_handler=None):
+        self.market_service_sub.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def req_market_detail(self, symbols: str, callback, error_handler=None):
         """
         Subscribe 24 hours trade statistics event. If statistics is generated,
         server will send the data to client and onReceive in callback will be called.
@@ -293,27 +310,31 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
-        self.market_service_socket.req_market_detail_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(request_market_detail_channel(symbol))
+                time.sleep(0.01)
 
-    def get_market_trade(self, symbol: 'str') -> list:
+        self.market_service_socket.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def get_market_trade(self, symbol: str) -> list:
         """
         Get the most recent trades with their price, volume and direction.
 
         :param symbol: The symbol, like "btcusdt". (mandatory)
         :return: The list of trade.
         """
+        channel = "/market/trade"
 
         check_symbol(symbol)
 
         params = {
             "symbol": symbol,
         }
-        return self.market_service.get_market_trade_service(params)
 
-    def get_history_trade(self, symbol: 'str', size: 'int' = None) -> list:
+        return self.market_service.request_process(HttpMethod.GET, channel, params)
+
+    def get_history_trade(self, symbol: str, size: 'int' = None) -> list:
         """
         Get the most recent trades with their price, volume and direction.
 
@@ -321,6 +342,7 @@ class MarketClient(object):
         :param size: The number of historical trade requested, range [1 - 2000] (optional)
         :return: The list of trade.
         """
+        channel = "/market/history/trade"
 
         check_symbol(symbol)
         check_range(size, 1, 2000, "size")
@@ -329,9 +351,10 @@ class MarketClient(object):
             "symbol": symbol,
             "size": size
         }
-        return self.market_service.get_history_trade_service(params)
 
-    def sub_trade_detail(self, symbols: 'str', callback, error_handler=None):
+        return self.market_service.request_process(HttpMethod.GET, channel, params)
+
+    def sub_trade_detail(self, symbols: str, callback, error_handler=None):
         """
         Subscribe price depth event. If the price depth is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -350,12 +373,14 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
-        self.market_service_sub.sub_trade_detail_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(trade_detail_channel(symbol))
+                time.sleep(0.01)
 
-    def req_trade_detail(self, symbols: 'str', callback, error_handler=None):
+        self.market_service_sub.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def req_trade_detail(self, symbols: str, callback, error_handler=None):
         """
         Subscribe price depth event. If the price depth is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -374,17 +399,20 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-        }
-        self.market_service_socket.req_trade_detail_service(callback, error_handler, params)
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(request_trade_detail_channel(symbol))
+                time.sleep(0.01)
+
+        self.market_service_socket.execute_subscribe_v1(subscription, callback, error_handler)
 
     def get_market_detail_merged(self, symbol):
         check_symbol(symbol)
         params = {
             "symbol": symbol
         }
-        return self.market_service.get_market_detail_merged_service(params)
+        channel = "/market/detail/merged"
+        return self.market_service.request_process(HttpMethod.GET, channel, params)
 
     def get_market_tickers(self) -> list:
         """
@@ -394,13 +422,14 @@ class MarketClient(object):
         """
 
         params = {}
-        return self.market_service.get_market_tickers_service(params)
+        channel = "/market/tickers"
+        return self.market_service.request_process(HttpMethod.GET, channel, params)
 
     """
     increase mbp(market by price)
     """
 
-    def sub_mbp_increase(self, symbols: 'str', levels: 'int', callback, error_handler=None):
+    def sub_mbp_increase(self, symbols: str, levels: 'int', callback, error_handler=None):
         """
         Subscribe mbp event. If the mbp is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -423,17 +452,24 @@ class MarketClient(object):
         check_should_not_none(levels, "levels")
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-            "levels": levels
-        }
-        return self.market_service_sub.sub_mbp_increase_service(callback, error_handler, params)
+        def mbp_increase_channel(symbol, level):
+            channel = dict()
+            channel["sub"] = "market.{symbol}.mbp.{level}".format(symbol=symbol, level=level)
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(mbp_increase_channel(symbol, levels))
+                time.sleep(0.01)
+
+        return self.market_service_sub.execute_subscribe_mbp(subscription, callback, error_handler)
 
     """
     subscribe full mbp(market by price)
     """
 
-    def sub_mbp_full(self, symbols: 'str', levels: 'int', callback, error_handler=None):
+    def sub_mbp_full(self, symbols: str, levels: 'int', callback, error_handler=None):
         """
         Subscribe full mbp event. If the mbp is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -457,13 +493,20 @@ class MarketClient(object):
         check_in_list(levels, [MbpLevel.MBP5, MbpLevel.MBP10, MbpLevel.MBP20], "levels")
         check_should_not_none(callback, "callback")
 
-        params = {
-            "symbol_list": symbol_list,
-            "levels": levels
-        }
-        self.market_service_sub.sub_mbp_full_service(callback, error_handler, params)
+        def mbp_full_channel(symbol, level):
+            channel = dict()
+            channel["sub"] = "market.{symbol}.mbp.refresh.{level}".format(symbol=symbol, level=level)
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
 
-    def req_mbp(self, symbols: 'str', levels: 'int', callback, auto_close=True, error_handler=None):
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(mbp_full_channel(symbol, levels))
+                time.sleep(0.01)
+
+        self.market_service_sub.execute_subscribe_v1(subscription, callback, error_handler)
+
+    def req_mbp(self, symbols: str, levels: 'int', callback, auto_close=True, error_handler=None):
         """
         Subscribe mbp event. If the mbp is updated,
         server will send the data to client and onReceive in callback will be called.
@@ -486,8 +529,16 @@ class MarketClient(object):
         check_symbol_list(symbol_list)
         check_should_not_none(levels, "levels")
         check_should_not_none(callback, "callback")
-        params = {
-            "symbol_list": symbol_list,
-            "levels": levels
-        }
-        self.market_service_socket.req_mbp_service(callback, error_handler, params)
+
+        def request_mbp_channel(symbol, level):
+            channel = dict()
+            channel["req"] = "market.{symbol}.mbp.{level}".format(symbol=symbol, level=level)
+            channel["id"] = str(get_current_timestamp())
+            return json.dumps(channel)
+
+        def subscription(connection):
+            for symbol in symbol_list:
+                connection.send(request_mbp_channel(symbol, levels))
+                time.sleep(0.01)
+
+        self.market_service_socket.execute_subscribe_mbp(subscription, callback, error_handler)
