@@ -1,5 +1,9 @@
 import logging
 
+from notecoin.huobi.connection.impl import (RestApiRequest, WebsocketManage,
+                                            WebsocketRequest,
+                                            WebSocketWatchDog, call_sync,
+                                            call_sync_perforence_test)
 from notecoin.huobi.constant.system import (ApiVersion, HttpMethod,
                                             WebSocketDefine,
                                             get_default_server_url)
@@ -7,9 +11,6 @@ from notecoin.huobi.exception.huobi_api_exception import HuobiApiException
 from notecoin.huobi.utils.api_signature import create_signature
 from notecoin.huobi.utils.url_params_builder import UrlParamsBuilder
 
-from .impl import (RestApiRequest, WebsocketManage, WebsocketRequest,
-                   WebSocketWatchDog, call_sync, call_sync_perforence_test)
-
 
 class RestApiSyncClient(object):
 
@@ -35,13 +36,13 @@ class RestApiSyncClient(object):
             handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
             logger.addHandler(handler)
 
-    def request_process(self, method, url, params, parse):
+    def request_process(self, method, url, params):
         if self.__performance_test is not None and self.__performance_test is True:
-            return self.request_process_performance(method, url, params, parse)
+            return self.request_process_performance(method, url, params)
         else:
-            return self.request_process_product(method, url, params, parse)
+            return self.request_process_product(method, url, params)
 
-    def create_request(self, method, url, params, parse):
+    def create_request(self, method, url, params):
         builder = UrlParamsBuilder()
         if params and len(params):
             if method in [HttpMethod.GET, HttpMethod.GET_SIGN]:
@@ -64,19 +65,17 @@ class RestApiSyncClient(object):
         else:
             raise HuobiApiException(HuobiApiException.INPUT_ERROR, "[Input] " + method + "  is invalid http method")
 
-        request.json_parser = parse
-
         return request
 
-    def request_process_product(self, method, url, params, parse):
-        request = self.create_request(method, url, params, parse)
+    def request_process_product(self, method, url, params):
+        request = self.create_request(method, url, params)
         if request:
             return call_sync(request)
 
         return None
 
-    def request_process_performance(self, method, url, params, parse):
-        request = self.create_request(method, url, params, parse)
+    def request_process_performance(self, method, url, params):
+        request = self.create_request(method, url, params)
         if request:
             return call_sync_perforence_test(request)
         return None, 0, 0
@@ -85,7 +84,7 @@ class RestApiSyncClient(object):
         for post batch operation, such as batch create orders[ /v1/order/batch-orders ]
         """
 
-    def create_request_post_batch(self, method, url, params, parse):
+    def create_request_post_batch(self, method, url, params):
         builder = UrlParamsBuilder()
         if params and len(params):
             if method in [HttpMethod.POST, HttpMethod.POST_SIGN]:
@@ -95,7 +94,6 @@ class RestApiSyncClient(object):
                 raise HuobiApiException(HuobiApiException.EXEC_ERROR, "[error] undefined HTTP method")
 
         request = self.__create_request_by_post_with_signature(url, builder)
-        request.json_parser = parse
 
         return request
 
@@ -103,21 +101,21 @@ class RestApiSyncClient(object):
     for post batch operation, such as batch create orders[ /v1/order/batch-orders ]
     """
 
-    def request_process_post_batch(self, method, url, params, parse):
+    def request_process_post_batch(self, method, url, params):
         if self.__performance_test is not None and self.__performance_test is True:
-            return self.request_process_post_batch_performance(method, url, params, parse)
+            return self.request_process_post_batch_performance(method, url, params)
         else:
-            return self.request_process_post_batch_product(method, url, params, parse)
+            return self.request_process_post_batch_product(method, url, params)
 
-    def request_process_post_batch_product(self, method, url, params, parse):
-        request = self.create_request_post_batch(method, url, params, parse)
+    def request_process_post_batch_product(self, method, url, params):
+        request = self.create_request_post_batch(method, url, params)
         if request:
             return call_sync(request)
 
         return None
 
-    def request_process_post_batch_performance(self, method, url, params, parse):
-        request = self.create_request_post_batch(method, url, params, parse)
+    def request_process_post_batch_performance(self, method, url, params):
+        request = self.create_request_post_batch(method, url, params)
         if request:
             return call_sync_perforence_test(request)
 
@@ -187,40 +185,40 @@ class SubscribeClient(object):
         manager.connect()
         SubscribeClient.subscribe_watch_dog.on_connection_created(manager)
 
-    def create_request(self, subscription_handler, parse, callback, error_handler, is_trade, is_mbp_feed=False):
+    def create_request(self, subscription_handler, callback, error_handler, is_trade, is_mbp_feed=False):
         request = WebsocketRequest()
         request.subscription_handler = subscription_handler
         request.is_trading = is_trade
         request.is_mbp_feed = is_mbp_feed
         request.auto_close = False  # subscribe need connection. websocket request need close request.
-        request.json_parser = parse
+
         request.update_callback = callback
         request.error_handler = error_handler
         return request
 
-    def create_request_v1(self, subscription_handler, parse, callback, error_handler, is_trade=False):
-        request = self.create_request(subscription_handler=subscription_handler, parse=parse, callback=callback,
+    def create_request_v1(self, subscription_handler, callback, error_handler, is_trade=False):
+        request = self.create_request(subscription_handler=subscription_handler, callback=callback,
                                       error_handler=error_handler, is_trade=is_trade)
         request.api_version = ApiVersion.VERSION_V1
         return request
 
-    def create_request_v2(self, subscription_handler, parse, callback, error_handler, is_trade=False):
-        request = self.create_request(subscription_handler=subscription_handler, parse=parse, callback=callback,
+    def create_request_v2(self, subscription_handler, callback, error_handler, is_trade=False):
+        request = self.create_request(subscription_handler=subscription_handler, callback=callback,
                                       error_handler=error_handler, is_trade=is_trade)
         request.api_version = ApiVersion.VERSION_V2
         return request
 
-    def execute_subscribe_v1(self, subscription_handler, parse, callback, error_handler, is_trade=False):
-        request = self.create_request_v1(subscription_handler, parse, callback, error_handler, is_trade)
+    def execute_subscribe_v1(self, subscription_handler, callback, error_handler, is_trade=False):
+        request = self.create_request_v1(subscription_handler, callback, error_handler, is_trade)
         self.__create_websocket_manage(request)
 
-    def execute_subscribe_v2(self, subscription_handler, parse, callback, error_handler, is_trade=False):
-        request = self.create_request_v2(subscription_handler, parse, callback, error_handler, is_trade)
+    def execute_subscribe_v2(self, subscription_handler, callback, error_handler, is_trade=False):
+        request = self.create_request_v2(subscription_handler, callback, error_handler, is_trade)
         self.__create_websocket_manage(request)
 
-    def execute_subscribe_mbp(self, subscription_handler, parse, callback, error_handler, is_trade=False,
+    def execute_subscribe_mbp(self, subscription_handler, callback, error_handler, is_trade=False,
                               is_mbp_feed=True):
-        request = self.create_request(subscription_handler, parse, callback, error_handler, is_trade, is_mbp_feed)
+        request = self.create_request(subscription_handler, callback, error_handler, is_trade, is_mbp_feed)
         self.__create_websocket_manage(request)
 
     def unsubscribe_all(self):
@@ -257,22 +255,22 @@ class WebSocketReqClient(object):
         manager = WebsocketManage(self.__api_key, self.__secret_key, self.__uri, request)
         manager.connect()
 
-    def create_request(self, subscription_handler, parse, callback, error_handler, is_trade=False, is_mbp_feed=False):
+    def create_request(self, subscription_handler, callback, error_handler, is_trade=False, is_mbp_feed=False):
         request = WebsocketRequest()
         request.subscription_handler = subscription_handler
         request.is_trading = is_trade
         request.is_mbp_feed = is_mbp_feed
         request.auto_close = True  # for websocket request, auto close the connection after request.
-        request.json_parser = parse
+
         request.update_callback = callback
         request.error_handler = error_handler
         return request
 
-    def execute_subscribe_v1(self, subscription_handler, parse, callback, error_handler, is_trade=False):
-        request = self.create_request(subscription_handler, parse, callback, error_handler, is_trade)
+    def execute_subscribe_v1(self, subscription_handler, callback, error_handler, is_trade=False):
+        request = self.create_request(subscription_handler, callback, error_handler, is_trade)
         self.__create_websocket_manage(request)
 
-    def execute_subscribe_mbp(self, subscription_handler, parse, callback, error_handler, is_trade=False,
+    def execute_subscribe_mbp(self, subscription_handler, callback, error_handler, is_trade=False,
                               is_mbp_feed=True):
-        request = self.create_request(subscription_handler, parse, callback, error_handler, is_trade, is_mbp_feed)
+        request = self.create_request(subscription_handler, callback, error_handler, is_trade, is_mbp_feed)
         self.__create_websocket_manage(request)
